ArrayLiteral class

Represents an array (list) literal.

Inheritance

Constructors

ArrayLiteral(int pos, List<Expression> items)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → List<Expression>
The items in the array.
final
pos → int
The starting position of the statement in the source text.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Returns the type name of the statement.
no setteroverride

Methods

execute(Context ctx) → JinjaValue
Executes the statement within the given ctx and returns the result as a JinjaValue.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited