CallExpression class
Represents a function or macro call expression.
- Inheritance
-
- Object
- Statement
- Expression
- CallExpression
Constructors
-
CallExpression(int pos, Expression callee, List<
Statement> args)
Properties
-
args
→ List<
Statement> -
The list of arguments passed to the call.
final
- callee → Expression
-
The expression that evaluates to the function to call.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pos → int
-
The starting position of the statement in the source text.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Returns the type name of the statement.
no setteroverride
Methods
-
execute(
Context ctx) → JinjaValue -
Executes the statement within the given
ctxand returns the result as a JinjaValue.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited