KeywordArgumentExpression class

Represents a keyword argument in a function or macro call.

Inheritance

Constructors

KeywordArgumentExpression(int pos, Expression key, Expression val)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Expression
The name of the argument.
final
pos → int
The starting position of the statement in the source text.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Returns the type name of the statement.
no setteroverride
val → Expression
The value of the argument.
final

Methods

execute(Context ctx) → JinjaValue
Executes the statement within the given ctx and returns the result as a JinjaValue.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited