LexerException class

Exception thrown when a lexical error is encountered.

Implemented types

Constructors

LexerException(String message, String source, int pos, [int? line, int? col])

Properties

col → int?
The column number where the error occurred (1-indexed).
final
hashCode → int
The hash code for this object.
no setterinherited
line → int?
The line number where the error occurred (1-indexed).
final
message → String
The error message.
final
pos → int
The position in the source where the error occurred.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
The source text being lexed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited