MacroStatement class

Represents a 'macro' definition.

Inheritance

Constructors

MacroStatement(int pos, Expression name, List<Expression> args, List<Statement> body)

Properties

args → List<Expression>
The list of arguments the macro accepts.
final
body → List<Statement>
The sequence of statements that form the macro's body.
final
hashCode → int
The hash code for this object.
no setterinherited
name → Expression
The name of the macro.
final
pos → int
The starting position of the statement in the source text.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Returns the type name of the statement.
no setteroverride

Methods

execute(Context ctx) → JinjaValue
Executes the statement within the given ctx and returns the result as a JinjaValue.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited