Program class

The root node of a Jinja template AST, containing a body of statements.

Inheritance

Constructors

Program(List<Statement> body)

Properties

body → List<Statement>
The list of statements that make up the template.
final
hashCode → int
The hash code for this object.
no setterinherited
pos → int
The starting position of the statement in the source text.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Returns the type name of the statement.
no setteroverride

Methods

execute(Context ctx) → JinjaValue
Renders the template. Input-marked text is escaped here, once.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited