SetStatement class

Represents a 'set' statement for variable assignment.

Inheritance

Constructors

SetStatement(int pos, Expression assignee, Expression? value, List<Statement> body)

Properties

assignee → Expression
The target for the assignment (e.g., Identifier or TupleLiteral).
final
body → List<Statement>
The body of the block assignment, used to capture output if value is null.
final
hashCode → int
The hash code for this object.
no setterinherited
pos → int
The starting position of the statement in the source text.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Returns the type name of the statement.
no setteroverride
value → Expression?
The expression whose value will be assigned. Null if it's a block assignment.
final

Methods

execute(Context ctx) → JinjaValue
Executes the statement within the given ctx and returns the result as a JinjaValue.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited