Statement class abstract

Base class for all nodes in the Jinja AST that represent a command or structure.

Implementers

Constructors

Statement(int pos)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pos → int
The starting position of the statement in the source text.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Returns the type name of the statement.
no setter

Methods

execute(Context ctx) → JinjaValue
Executes the statement within the given ctx and returns the result as a JinjaValue.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited