execute abstract method
Executes the statement within the given ctx and returns the result as a JinjaValue.
Implementation
JinjaValue execute(Context ctx);
Executes the statement within the given ctx and returns the result as a JinjaValue.
JinjaValue execute(Context ctx);