execute method
Executes the statement within the given ctx and returns the result as a JinjaValue.
Implementation
@override
JinjaValue execute(Context ctx) =>
JinjaStringValue(JinjaString.from(value, isSafe: isSafe));
Executes the statement within the given ctx and returns the result as a JinjaValue.
@override
JinjaValue execute(Context ctx) =>
JinjaStringValue(JinjaString.from(value, isSafe: isSafe));