TestExpression class

Represents a test application (e.g., val is defined).

Inheritance

Constructors

TestExpression(int pos, Expression operand, bool negate, Expression test)

Properties

hashCode → int
The hash code for this object.
no setterinherited
negate → bool
Whether the test is negated (is not).
final
operand → Expression
The value being tested.
final
pos → int
The starting position of the statement in the source text.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
test → Expression
The test to perform.
final
type → String
Returns the type name of the statement.
no setteroverride

Methods

execute(Context ctx) → JinjaValue
Executes the statement within the given ctx and returns the result as a JinjaValue.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited