execute method
Executes the statement within the given ctx and returns the result as a JinjaValue.
Implementation
@override
JinjaValue execute(Context ctx) {
return JinjaTuple(items.map((e) => e.execute(ctx)).toList());
}
Executes the statement within the given ctx and returns the result as a JinjaValue.
@override
JinjaValue execute(Context ctx) {
return JinjaTuple(items.map((e) => e.execute(ctx)).toList());
}