CallStatement class
Represents a 'call' block, used to invoke a macro with block content.
Constructors
-
CallStatement(int pos, CallExpression call, List<
Statement> callerArgs, List<Statement> body)
Properties
-
body
→ List<
Statement> -
The block content passed to the macro.
final
- call → CallExpression
-
The macro call expression.
final
-
callerArgs
→ List<
Statement> -
Optional arguments for the caller.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pos → int
-
The starting position of the statement in the source text.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Returns the type name of the statement.
no setteroverride
Methods
-
execute(
Context ctx) → JinjaValue -
Executes the statement within the given
ctxand returns the result as a JinjaValue.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited