IfStatement class
Represents a conditional 'if' block.
Constructors
-
IfStatement(int pos, Expression test, List<
Statement> body, List<Statement> alternate)
Properties
-
alternate
→ List<
Statement> -
The statements to execute if the condition is false.
final
-
body
→ List<
Statement> -
The statements to execute if the condition is true.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pos → int
-
The starting position of the statement in the source text.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- test → Expression
-
The condition expression to evaluate.
final
- type → String
-
Returns the type name of the statement.
no setteroverride
Methods
-
execute(
Context ctx) → JinjaValue -
Executes the statement within the given
ctxand returns the result as a JinjaValue.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited