MemberExpression class
Represents a member access expression (e.g., obj.prop or obj[expr]).
- Inheritance
-
- Object
- Statement
- Expression
- MemberExpression
Constructors
- MemberExpression(int pos, Expression object, Expression property, {required bool computed})
Properties
- computed → bool
-
Whether the access is computed (using
[]) or not (using.).final - hashCode → int
-
The hash code for this object.
no setterinherited
- object → Expression
-
The object being accessed.
final
- pos → int
-
The starting position of the statement in the source text.
finalinherited
- property → Expression
-
The property or index being accessed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Returns the type name of the statement.
no setteroverride
Methods
-
execute(
Context ctx) → JinjaValue -
Executes the statement within the given
ctxand returns the result as a JinjaValue.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited